<?xml version="1.0" encoding="iso-8859-1"?>

<!--
text.xsl

Copyright (c) 2001,2002 Florent Villard (warly@laposte.net)
Published under the GPL license.
-->

<xsl:stylesheet version="1.0"
	 xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="iso-8859-1"/>
  <xsl:output doctype-public="-//W3C//DTD HTML 4.0//EN"/>
  <xsl:strip-space elements="*"/>

  <xsl:template match="/">
	  <xsl:apply-templates select="vie"/>
  </xsl:template>

  <xsl:template name="newLine">
<xsl:text>
</xsl:text>
  </xsl:template>
  
  <xsl:template name="nNewLine">
    <xsl:param name="n" select="0"/>
    <xsl:if test="$n &gt; 0">
    <xsl:call-template name="newLine"/>
    <xsl:call-template name="nNewLine">
      <xsl:with-param name="n" select="$n - 1" />
    </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template name="nSpace">
    <xsl:param name="n" select="0"/>
    <xsl:if test="$n &gt; 0">
    <xsl:text> </xsl:text>
    <xsl:call-template name="nSpace">
    <xsl:with-param name="n" select="$n - 1" />
    </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template name="nChar">
    <xsl:param name="n" select="0"/>
    <xsl:param name="char"/>
    <xsl:if test="$n &gt; 0">
      <xsl:value-of select="$char"/>
      <xsl:call-template name="nChar">
        <xsl:with-param name="n" select="$n - 1" />
        <xsl:with-param name="char"> 
          <xsl:value-of select="$char"/>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template name="center">
    <xsl:param name="text"/>
    <xsl:param name="width" select="80"/> 
    <xsl:call-template name="newLine"/>
    <xsl:call-template name="nSpace">
      <xsl:with-param name="n" select="($width - string-length($text)) div 2" />
    </xsl:call-template>
    <xsl:value-of select="$text"/>
    <xsl:call-template name="newLine"/>
  </xsl:template>

 <xsl:template name="replace">
    <xsl:param name="text"/>
    <xsl:param name="char1"/>
    <xsl:param name="char2"/>
    <xsl:choose>
      <xsl:when test="contains($text,$char1)">
        <xsl:value-of select="substring-before($text,$char1)"/>
        <xsl:value-of select="$char2"/>
        <xsl:call-template name="replace">
          <xsl:with-param name="char1">
             <xsl:value-of select="$char1"/>
          </xsl:with-param>
          <xsl:with-param name="char2">
             <xsl:value-of select="$char2"/>
          </xsl:with-param>
          <xsl:with-param name="text" select="substring-after($text,$char1)"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$text"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

 <xsl:template name="justify" >
    <xsl:param name="text"  />
    <xsl:param name="width" select="80"/>
    <xsl:param name="pos"  select="0" /> 
    
    <xsl:call-template name="justifyText">
      <xsl:with-param name="width" select="$width"/>
      <xsl:with-param name="pos" select="0"/> 
      <xsl:with-param name="text">
         <xsl:call-template name="replace">
           <xsl:with-param name="text">
             <xsl:value-of select="$text"/>
           </xsl:with-param>
           <xsl:with-param name="char1">
             <xsl:text>&#xa;</xsl:text>
           </xsl:with-param>
           <xsl:with-param name="char2">
             <xsl:text> </xsl:text>
           </xsl:with-param>
         </xsl:call-template>     
       </xsl:with-param>
    </xsl:call-template>       
  </xsl:template>

  <xsl:template name="justifyText">
    <xsl:param name="text"  />
    <xsl:param name="width" select="80"/>
    <xsl:param name="pos"  select="0" /> 
   <xsl:if test="$pos=0">
    <xsl:call-template name="newLine"/>
   </xsl:if>
   <xsl:if test="string-length($text) > 0">
    <xsl:choose>
        <xsl:when test="contains($text,' ')">
            <xsl:variable name="word" select="substring-before($text,' ')"/>
               <xsl:value-of select="$word"/>
              <xsl:if test="(1 + $pos + string-length($word)) &gt; $width">
                  <xsl:call-template name="justifyText">
                    <xsl:with-param name="text" select="substring-after($text,' ')"/>
                    <xsl:with-param name="width" select="$width"/>
                    <xsl:with-param name="pos" select="0"/>
                  </xsl:call-template>
              </xsl:if>
              <xsl:if test="($pos + string-length($word)) &lt; $width">
                  <xsl:text> </xsl:text>
                  <xsl:call-template name="justifyText">
                    <xsl:with-param name="text" select="substring-after($text,' ')"/>
                    <xsl:with-param name="width" select="$width"/>
                    <xsl:with-param name="pos" select="$pos + string-length($word) + 1"/>
                  </xsl:call-template>
              </xsl:if>
        </xsl:when>
        <xsl:otherwise><xsl:value-of select="$text"/></xsl:otherwise>
    </xsl:choose>
   </xsl:if>
 </xsl:template>

  <xsl:template name="makeTitle">
    <xsl:param name="text"/>
    <xsl:call-template name="newLine"/>
    <xsl:call-template name="newLine"/>
    <xsl:value-of select="$text"/>
    <xsl:call-template name="newLine"/>
    <xsl:call-template name="nChar">
      <xsl:with-param name="n" select="(string-length($text))" />
      <xsl:with-param name="char"> 
        <xsl:text>-</xsl:text>
      </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="newLine"/>
  </xsl:template>

  <xsl:template match="/vie">
	<xsl:apply-templates select="header"/>
	<xsl:call-template name="nNewLine"/>
	<xsl:apply-templates select="body"/>
  </xsl:template>

  <xsl:template match="header">
	<xsl:call-template name="nNewLine">
          <xsl:with-param name="n" select="5"/>
        </xsl:call-template>	

        <xsl:call-template name="center">
           <xsl:with-param name="text">
             <xsl:value-of select="doctitle"/>
           </xsl:with-param>
        </xsl:call-template>
	
	<xsl:call-template name="newLine"/>
        
	<xsl:call-template name="center">
           <xsl:with-param name="text">
             <xsl:value-of select="booktitle"/>
           </xsl:with-param>
        </xsl:call-template>

	<xsl:call-template name="newLine"/>

	<xsl:call-template name="center">
           <xsl:with-param name="text">
             <xsl:apply-templates select="author"/>
           </xsl:with-param>
        </xsl:call-template>
        
	<xsl:call-template name="newLine"/>

        <xsl:call-template name="center">
           <xsl:with-param name="text">
             <xsl:value-of select="date"/>
           </xsl:with-param>
        </xsl:call-template>

	<xsl:call-template name="newLine"/>

	<xsl:call-template name="nNewLine">
          <xsl:with-param name="n" select="10"/>
        </xsl:call-template>
	
        <xsl:apply-templates select="version"/>
	<xsl:call-template name="newLine"/>
	<xsl:apply-templates select="copyright"/>
	<xsl:call-template name="newLine"/>
	<xsl:apply-templates select="(gpl|cc)"/>
	<xsl:call-template name="newLine"/>
  </xsl:template>

  <xsl:template match="author">
	<xsl:value-of select="firstname"/>
	<xsl:text> (</xsl:text>
	<xsl:value-of select="surname"/>
	<xsl:text>) </xsl:text>
	<xsl:value-of select="lastname"/>
  </xsl:template>

  <xsl:template match="date">
	<xsl:call-template name="newLine"/>
	<xsl:value-of select="."/>
	<xsl:call-template name="newLine"/>
  </xsl:template>

  <xsl:template match="copyright">
	<xsl:call-template name="newLine"/>
	<xsl:text>Copyright </xsl:text>
	<xsl:value-of select="year"/>
	<xsl:text> </xsl:text>
        <xsl:value-of select="holder"/>
	<xsl:call-template name="newLine"/>
        <xsl:value-of select="license"/>
	<xsl:call-template name="newLine"/>
        <xsl:value-of select="licensetext"/>
	<xsl:call-template name="newLine"/>
  </xsl:template>

  <xsl:template match="gpl">
<xsl:text>Cette cration est mise  disposition selon le Contrat
Paternit - Partage des Conditions Initiales  l'Identique
disponible en ligne
http://creativecommons.org/licenses/by-sa/2.0/fr/ ou par courrier
postal  Creative Commons, 559 Nathan Abbott Way, Stanford,
California 94305, USA.</xsl:text>
  </xsl:template>

  <xsl:template match="gpl">
	<xsl:text>Ce programme est un logiciel libre; vous pouvez le redistribuer
et/ou le modifier selon les termes de la GNU General Public
License (Licence Publique Gnrale GNU) telle qu'elle a t
publie par la Free Software Foundation; soit la version 2 de de
la licence, soit (comme vous le souhaitez) toute version
ultrieure.

Ce programme est distribu dans l'espoir qu'il sera utile, mais
SANS LA MOINDRE GARANTIE; pas mme la garantie implicite de
COMMERCIABILITE ou d'ADEQUATION A UN BUT PARTICULIER. Voir la GNU
General Public License pour plus de dtails.

Vous devriez avoir reu une copie de la GNU General Public License
en mme temps que ce programme; sinon, merci d'crire  la Free
Software Foundation, Inc, 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA</xsl:text>
  </xsl:template>

  <xsl:template match="version">
	<xsl:text>Version: </xsl:text><xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="body">
	<xsl:call-template name="makeTitle">
          <xsl:with-param name="text">
	    <xsl:value-of select="title"/>
          </xsl:with-param>
        </xsl:call-template>

	<xsl:apply-templates select="acknowledgments"/>
	<xsl:apply-templates select="prface"/>
	<xsl:apply-templates select="(part|chapter|section|para|day|table)"/>
  </xsl:template>

  <xsl:template match="part">
	<xsl:call-template name="makeTitle">
          <xsl:with-param name="text">
	    <xsl:value-of select="title"/>
          </xsl:with-param>
        </xsl:call-template>

	<xsl:call-template name="newLine"/>
        <xsl:apply-templates select="(para|chapter|section|day|table|gpltext)"/>
  </xsl:template>

  <xsl:template match="day">
        <xsl:call-template name="makeTitle">
          <xsl:with-param name="text">
	    <xsl:value-of select="."/>
          </xsl:with-param>
        </xsl:call-template>
	<xsl:call-template name="newLine"/>
  </xsl:template>

 <xsl:template match="chapter">
        <xsl:call-template name="makeTitle">
          <xsl:with-param name="text">
	    <xsl:value-of select="title"/>
          </xsl:with-param>
        </xsl:call-template>
	<xsl:call-template name="newLine"/>
	<xsl:apply-templates select="(para|section|day|table)"/>
  </xsl:template>


   <xsl:template match="table">
          <xsl:apply-templates select="(titlerow|row)"/>
  </xsl:template>

  <xsl:template match="titlerow">
|	<xsl:apply-templates select="(titleentry)"/>
------------------------------------------------------------------------        
    <xsl:call-template name="newLine"/>
  </xsl:template>

  <xsl:template match="row">
| <xsl:apply-templates select="(entry)"/>
          <xsl:call-template name="newLine"/>
  </xsl:template>

  <xsl:template match="titleentry">
        <xsl:value-of select="."/> | </xsl:template>

  <xsl:template match="entry">
         <xsl:value-of select="."/> | </xsl:template>

  <xsl:template match="gpltext">
        <xsl:call-template name="makeTitle">
          <xsl:with-param name="text">GNU General Public License</xsl:with-param>
        </xsl:call-template>
    <xsl:call-template name="newLine"/>
	<xsl:text>General Public License applies to most of the Free Software
Foundation's software and to any other program whose authors commit to
using it.  (Some other Free Software Foundation software is covered by
the GNU Library General Public License instead.)  You can apply it to
your programs, too.

  When we speak of free software, we are referring to freedom, not
price.  Our General Public Licenses are designed to make sure that you
have the freedom to distribute copies of free software (and charge for
this service if you wish), that you receive source code or can get it
if you want it, that you can change the software or use pieces of it
in new free programs; and that you know you can do these things.

  To protect your rights, we need to make restrictions that forbid
anyone to deny you these rights or to ask you to surrender the rights.
These restrictions translate to certain responsibilities for you if you
distribute copies of the software, or if you modify it.

  For example, if you distribute copies of such a program, whether
gratis or for a fee, you must give the recipients all the rights that
you have.  You must make sure that they, too, receive or can get the
source code.  And you must show them these terms so they know their
rights.

  We protect your rights with two steps: (1) copyright the software, and
(2) offer you this license which gives you legal permission to copy,
distribute and/or modify the software.

  Also, for each author's protection and ours, we want to make certain
that everyone understands that there is no warranty for this free
software.  If the software is modified by someone else and passed on, we
want its recipients to know that what they have is not the original, so
that any problems introduced by others will not reflect on the original
authors' reputations.

  Finally, any free program is threatened constantly by software
patents.  We wish to avoid the danger that redistributors of a free
program will individually obtain patent licenses, in effect making the
program proprietary.  To prevent this, we have made it clear that any
patent must be licensed for everyone's free use or not licensed at all.

  The precise terms and conditions for copying, distribution and
modification follow.

		    GNU GENERAL PUBLIC LICENSE
   TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION

  0. This License applies to any program or other work which contains
a notice placed by the copyright holder saying it may be distributed
under the terms of this General Public License.  The "Program", below,
refers to any such program or work, and a "work based on the Program"
means either the Program or any derivative work under copyright law:
that is to say, a work containing the Program or a portion of it,
either verbatim or with modifications and/or translated into another
language.  (Hereinafter, translation is included without limitation in
the term "modification".)  Each licensee is addressed as "you".

Activities other than copying, distribution and modification are not
covered by this License; they are outside its scope.  The act of
running the Program is not restricted, and the output from the Program
is covered only if its contents constitute a work based on the
Program (independent of having been made by running the Program).
Whether that is true depends on what the Program does.

  1. You may copy and distribute verbatim copies of the Program's
source code as you receive it, in any medium, provided that you
conspicuously and appropriately publish on each copy an appropriate
copyright notice and disclaimer of warranty; keep intact all the
notices that refer to this License and to the absence of any warranty;
and give any other recipients of the Program a copy of this License
along with the Program.

You may charge a fee for the physical act of transferring a copy, and
you may at your option offer warranty protection in exchange for a fee.

  2. You may modify your copy or copies of the Program or any portion
of it, thus forming a work based on the Program, and copy and
distribute such modifications or work under the terms of Section 1
above, provided that you also meet all of these conditions:

    a) You must cause the modified files to carry prominent notices
    stating that you changed the files and the date of any change.

    b) You must cause any work that you distribute or publish, that in
    whole or in part contains or is derived from the Program or any
    part thereof, to be licensed as a whole at no charge to all third
    parties under the terms of this License.

    c) If the modified program normally reads commands interactively
    when run, you must cause it, when started running for such
    interactive use in the most ordinary way, to print or display an
    announcement including an appropriate copyright notice and a
    notice that there is no warranty (or else, saying that you provide
    a warranty) and that users may redistribute the program under
    these conditions, and telling the user how to view a copy of this
    License.  (Exception: if the Program itself is interactive but
    does not normally print such an announcement, your work based on
    the Program is not required to print an announcement.)

These requirements apply to the modified work as a whole.  If
identifiable sections of that work are not derived from the Program,
and can be reasonably considered independent and separate works in
themselves, then this License, and its terms, do not apply to those
sections when you distribute them as separate works.  But when you
distribute the same sections as part of a whole which is a work based
on the Program, the distribution of the whole must be on the terms of
this License, whose permissions for other licensees extend to the
entire whole, and thus to each and every part regardless of who wrote it.

Thus, it is not the intent of this section to claim rights or contest
your rights to work written entirely by you; rather, the intent is to
exercise the right to control the distribution of derivative or
collective works based on the Program.

In addition, mere aggregation of another work not based on the Program
with the Program (or with a work based on the Program) on a volume of
a storage or distribution medium does not bring the other work under
the scope of this License.

  3. You may copy and distribute the Program (or a work based on it,
under Section 2) in object code or executable form under the terms of
Sections 1 and 2 above provided that you also do one of the following:

    a) Accompany it with the complete corresponding machine-readable
    source code, which must be distributed under the terms of Sections
    1 and 2 above on a medium customarily used for software interchange; or,

    b) Accompany it with a written offer, valid for at least three
    years, to give any third party, for a charge no more than your
    cost of physically performing source distribution, a complete
    machine-readable copy of the corresponding source code, to be
    distributed under the terms of Sections 1 and 2 above on a medium
    customarily used for software interchange; or,

    c) Accompany it with the information you received as to the offer
    to distribute corresponding source code.  (This alternative is
    allowed only for noncommercial distribution and only if you
    received the program in object code or executable form with such
    an offer, in accord with Subsection b above.)

The source code for a work means the preferred form of the work for
making modifications to it.  For an executable work, complete source
code means all the source code for all modules it contains, plus any
associated interface definition files, plus the scripts used to
control compilation and installation of the executable.  However, as a
special exception, the source code distributed need not include
anything that is normally distributed (in either source or binary
form) with the major components (compiler, kernel, and so on) of the
operating system on which the executable runs, unless that component
itself accompanies the executable.

If distribution of executable or object code is made by offering
access to copy from a designated place, then offering equivalent
access to copy the source code from the same place counts as
distribution of the source code, even though third parties are not
compelled to copy the source along with the object code.

  4. You may not copy, modify, sublicense, or distribute the Program
except as expressly provided under this License.  Any attempt
otherwise to copy, modify, sublicense or distribute the Program is
void, and will automatically terminate your rights under this License.
However, parties who have received copies, or rights, from you under
this License will not have their licenses terminated so long as such
parties remain in full compliance.

  5. You are not required to accept this License, since you have not
signed it.  However, nothing else grants you permission to modify or
distribute the Program or its derivative works.  These actions are
prohibited by law if you do not accept this License.  Therefore, by
modifying or distributing the Program (or any work based on the
Program), you indicate your acceptance of this License to do so, and
all its terms and conditions for copying, distributing or modifying
the Program or works based on it.

  6. Each time you redistribute the Program (or any work based on the
Program), the recipient automatically receives a license from the
original licensor to copy, distribute or modify the Program subject to
these terms and conditions.  You may not impose any further
restrictions on the recipients' exercise of the rights granted herein.
You are not responsible for enforcing compliance by third parties to
this License.

  7. If, as a consequence of a court judgment or allegation of patent
infringement or for any other reason (not limited to patent issues),
conditions are imposed on you (whether by court order, agreement or
otherwise) that contradict the conditions of this License, they do not
excuse you from the conditions of this License.  If you cannot
distribute so as to satisfy simultaneously your obligations under this
License and any other pertinent obligations, then as a consequence you
may not distribute the Program at all.  For example, if a patent
license would not permit royalty-free redistribution of the Program by
all those who receive copies directly or indirectly through you, then
the only way you could satisfy both it and this License would be to
refrain entirely from distribution of the Program.

If any portion of this section is held invalid or unenforceable under
any particular circumstance, the balance of the section is intended to
apply and the section as a whole is intended to apply in other
circumstances.

It is not the purpose of this section to induce you to infringe any
patents or other property right claims or to contest validity of any
such claims; this section has the sole purpose of protecting the
integrity of the free software distribution system, which is
implemented by public license practices.  Many people have made
generous contributions to the wide range of software distributed
through that system in reliance on consistent application of that
system; it is up to the author/donor to decide if he or she is willing
to distribute software through any other system and a licensee cannot
impose that choice.

This section is intended to make thoroughly clear what is believed to
be a consequence of the rest of this License.

  8. If the distribution and/or use of the Program is restricted in
certain countries either by patents or by copyrighted interfaces, the
original copyright holder who places the Program under this License
may add an explicit geographical distribution limitation excluding
those countries, so that distribution is permitted only in or among
countries not thus excluded.  In such case, this License incorporates
the limitation as if written in the body of this License.

  9. The Free Software Foundation may publish revised and/or new versions
of the General Public License from time to time.  Such new versions will
be similar in spirit to the present version, but may differ in detail to
address new problems or concerns.

Each version is given a distinguishing version number.  If the Program
specifies a version number of this License which applies to it and "any
later version", you have the option of following the terms and conditions
either of that version or of any later version published by the Free
Software Foundation.  If the Program does not specify a version number of
this License, you may choose any version ever published by the Free Software
Foundation.

  10. If you wish to incorporate parts of the Program into other free
programs whose distribution conditions are different, write to the author
to ask for permission.  For software which is copyrighted by the Free
Software Foundation, write to the Free Software Foundation; we sometimes
make exceptions for this.  Our decision will be guided by the two goals
of preserving the free status of all derivatives of our free software and
of promoting the sharing and reuse of software generally.

			    NO WARRANTY

  11. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW.  EXCEPT WHEN
OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED
OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE ENTIRE RISK AS
TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU.  SHOULD THE
PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING,
REPAIR OR CORRECTION.

  12. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES,
INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING
OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED
TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY
YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER
PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE
POSSIBILITY OF SUCH DAMAGES.

		     END OF TERMS AND CONDITIONS
</xsl:text>
  </xsl:template>

 <xsl:template match="acknowledgments">
        <xsl:call-template name="makeTitle">
          <xsl:with-param name="text">
	    <xsl:text>Remerciements</xsl:text>
          </xsl:with-param>
        </xsl:call-template>
	<xsl:call-template name="newLine"/>
	<xsl:apply-templates select="para"/>
  </xsl:template>

  <xsl:template match="preface">
        <xsl:call-template name="makeTitle">
          <xsl:with-param name="text">
	    <xsl:text>Preface</xsl:text>
          </xsl:with-param>
        </xsl:call-template>
	<xsl:call-template name="newLine"/>
	<xsl:apply-templates select="para"/>
  </xsl:template>

  <xsl:template match="section">
        <xsl:call-template name="makeTitle">
          <xsl:with-param name="text">
	    <xsl:value-of select="title"/>
          </xsl:with-param>
        </xsl:call-template>

	<xsl:call-template name="newLine"/>
	<xsl:apply-templates select="(para|day)"/>
  </xsl:template>
   
  <xsl:template match="para">
    <xsl:call-template name="newLine"/>
    <xsl:call-template name="justify">
      <xsl:with-param name="text">
        <xsl:value-of select="."/>
      </xsl:with-param>
      <xsl:with-param name="width" select="80"/>
    </xsl:call-template>
  </xsl:template>

</xsl:stylesheet>
